@@ -1,5 +1,5 @@
 from dataclasses import dataclass
-from typing import Literal, Type, TypeVar
+from typing import Literal, Type, TypeVar, get_type_hints
 
 from pydantic import BaseSettings
 
@@ -22,8 +22,12 @@ class LoggingConfig(BaseSettings):
     format: Literal["console", "json"] = "console"
 
 
+class RabbitMQConfig(BaseSettings):
+    url: str
+
+
 AnyConfig = TypeVar("AnyConfig", bound=BaseSettings)
-ChloreConfig = TypeVar("ChloreConfig", AuthConfig, LoggingConfig, DatabaseConfig)
+ChloreConfig = TypeVar("ChloreConfig", AuthConfig, DatabaseConfig, LoggingConfig, RabbitMQConfig)
 
 
 @dataclass
@@ -31,16 +35,13 @@ class _InternalConfig:
     auth: AuthConfig = None
     logging: LoggingConfig = None
     database: DatabaseConfig = None
+    rabbitmq: RabbitMQConfig = None
 
     def wants(self, type: Type[AnyConfig]) -> bool:
         return type in ChloreConfig.__constraints__
 
     def register(self, type: Type[ChloreConfig], value: ChloreConfig):
-        table = {
-            AuthConfig: "auth",
-            LoggingConfig: "logging",
-            DatabaseConfig: "database",
-        }
+        table = {type: field_name for field_name, type in get_type_hints(_InternalConfig).items()}
         setattr(self, table[type], value)
 
 
